@@ -27,6 +27,7 @@ from astropy.io.fits.util import (
 )
 from astropy.io.fits.verify import _ErrList, _Verify
 from astropy.utils import lazyproperty
+from astropy.utils.decorators import deprecated
 from astropy.utils.exceptions import AstropyUserWarning
 
 __all__ = [
@@ -109,7 +110,11 @@ def _hdu_class_from_header(cls, header):
                     or c in cls._hdu_registry
                 ):
                     continue
-                if c.match_header(header):
+                # skip _NonstandardExtHDU and _ExtensionHDU since those are deprecated
+                if c.match_header(header) and c not in (
+                    _NonstandardExtHDU,
+                    _ExtensionHDU,
+                ):
                     klass = c
                     break
             except NotImplementedError:
@@ -117,7 +122,7 @@ def _hdu_class_from_header(cls, header):
             except Exception as exc:
                 warnings.warn(
                     "An exception occurred matching an HDU header to the "
-                    "appropriate HDU type: {}".format(exc),
+                    f"appropriate HDU type: {exc}",
                     AstropyUserWarning,
                 )
                 warnings.warn(
@@ -306,7 +311,7 @@ class _BaseHDU:
 
         Parameters
         ----------
-        data : str, bytearray, memoryview, ndarray
+        data : str, bytes, memoryview, ndarray
             A byte string containing the HDU's header and data.
 
         checksum : bool, optional
@@ -382,7 +387,7 @@ class _BaseHDU:
             Output verification option.  Must be one of ``"fix"``,
             ``"silentfix"``, ``"ignore"``, ``"warn"``, or
             ``"exception"``.  May also be any combination of ``"fix"`` or
-            ``"silentfix"`` with ``"+ignore"``, ``+warn``, or ``+exception"
+            ``"silentfix"`` with ``"+ignore"``, ``"+warn"``, or ``"+exception"``
             (e.g. ``"fix+warn"``).  See :ref:`astropy:verify` for more info.
 
         overwrite : bool, optional
@@ -855,16 +860,7 @@ class _NonstandardHDU(_BaseHDU, _Verify):
         """
         # The SIMPLE keyword must be in the first card
         card = header.cards[0]
-
-        # The check that 'GROUPS' is missing is a bit redundant, since the
-        # match_header for GroupsHDU will always be called before this one.
-        if card.keyword == "SIMPLE":
-            if "GROUPS" not in header and card.value is False:
-                return True
-            else:
-                raise InvalidHDUException
-        else:
-            return False
+        return card.keyword == "SIMPLE" and card.value is False
 
     @property
     def size(self):
@@ -1067,8 +1063,8 @@ class _ValidHDU(_BaseHDU, _Verify):
                             raise ValueError
                     except ValueError:
                         err_text = (
-                            "NAXISj keyword out of range ('{}' when "
-                            "NAXIS == {})".format(keyword, naxis)
+                            f"NAXISj keyword out of range ('{keyword}' when "
+                            f"NAXIS == {naxis})"
                         )
 
                         def fix(self=self, keyword=keyword):
@@ -1622,9 +1618,9 @@ class ExtensionHDU(_ValidHDU):
         return errs
 
 
-# For backwards compatibility, though this needs to be deprecated
-# TODO: Mark this as deprecated
-_ExtensionHDU = ExtensionHDU
+@deprecated("v6.0")
+class _ExtensionHDU(ExtensionHDU):
+    pass
 
 
 class NonstandardExtHDU(ExtensionHDU):
@@ -1671,5 +1667,6 @@ class NonstandardExtHDU(ExtensionHDU):
         return self._get_raw_data(self.size, "ubyte", self._data_offset)
 
 
-# TODO: Mark this as deprecated
-_NonstandardExtHDU = NonstandardExtHDU
+@deprecated("v6.0")
+class _NonstandardExtHDU(NonstandardExtHDU):
+    pass
