@@ -17,7 +17,7 @@ import numpy as np
 
 # LOCAL
 from astropy import config as _config
-from astropy.utils.compat import NUMPY_LT_1_22
+from astropy.utils.compat.numpycompat import NUMPY_LT_2_0
 from astropy.utils.data_info import ParentDtypeInfo
 from astropy.utils.decorators import deprecated
 from astropy.utils.exceptions import AstropyWarning
@@ -133,7 +133,7 @@ class QuantityIterator:
     def __len__(self):
         return len(self._dataiter)
 
-    #### properties and methods to match `numpy.ndarray.flatiter` ####
+    # Properties and methods to match `numpy.ndarray.flatiter`
 
     @property
     def base(self):
@@ -716,7 +716,10 @@ class Quantity(np.ndarray):
         if isinstance(result, (tuple, list)):
             if out is None:
                 out = (None,) * len(result)
-            return result.__class__(
+            # Some np.linalg functions return namedtuple, which is handy to access
+            # elements by name, but cannot be directly initialized with an iterator.
+            result_cls = getattr(result, "_make", result.__class__)
+            return result_cls(
                 self._result_as_quantity(result_, unit_, out_)
                 for (result_, unit_, out_) in zip(result, unit, out)
             )
@@ -1692,11 +1695,13 @@ class Quantity(np.ndarray):
             _value = _value.astype(self.dtype, copy=False)
         return _value
 
-    def itemset(self, *args):
-        if len(args) == 0:
-            raise ValueError("itemset must have at least one argument")
+    if NUMPY_LT_2_0:
 
-        self.view(np.ndarray).itemset(*(args[:-1] + (self._to_own_unit(args[-1]),)))
+        def itemset(self, *args):
+            if len(args) == 0:
+                raise ValueError("itemset must have at least one argument")
+
+            self.view(np.ndarray).itemset(*(args[:-1] + (self._to_own_unit(args[-1]),)))
 
     def tostring(self, order="C"):
         """Not implemented, use ``.value.tostring()`` instead."""
@@ -1782,21 +1787,11 @@ class Quantity(np.ndarray):
             np.array(self), self._to_own_unit(v, check_precision=False), *args, **kwargs
         )  # avoid numpy 1.6 problem
 
-    if NUMPY_LT_1_22:
+    def argmax(self, axis=None, out=None, *, keepdims=False):
+        return self.view(np.ndarray).argmax(axis=axis, out=out, keepdims=keepdims)
 
-        def argmax(self, axis=None, out=None):
-            return self.view(np.ndarray).argmax(axis, out=out)
-
-        def argmin(self, axis=None, out=None):
-            return self.view(np.ndarray).argmin(axis, out=out)
-
-    else:
-
-        def argmax(self, axis=None, out=None, *, keepdims=False):
-            return self.view(np.ndarray).argmax(axis=axis, out=out, keepdims=keepdims)
-
-        def argmin(self, axis=None, out=None, *, keepdims=False):
-            return self.view(np.ndarray).argmin(axis=axis, out=out, keepdims=keepdims)
+    def argmin(self, axis=None, out=None, *, keepdims=False):
+        return self.view(np.ndarray).argmin(axis=axis, out=out, keepdims=keepdims)
 
     def __array_function__(self, function, types, args, kwargs):
         """Wrap numpy functions, taking care of units.
@@ -2008,28 +2003,18 @@ class Quantity(np.ndarray):
     def ediff1d(self, to_end=None, to_begin=None):
         return self._wrap_function(np.ediff1d, to_end, to_begin)
 
-    if NUMPY_LT_1_22:
-
-        @deprecated("5.3", alternative="np.nansum", obj_type="method")
-        def nansum(self, axis=None, out=None, keepdims=False):
-            return self._wrap_function(np.nansum, axis, out=out, keepdims=keepdims)
-
-    else:
-
-        @deprecated("5.3", alternative="np.nansum", obj_type="method")
-        def nansum(
-            self, axis=None, out=None, keepdims=False, *, initial=None, where=True
-        ):
-            if initial is not None:
-                initial = self._to_own_unit(initial)
-            return self._wrap_function(
-                np.nansum,
-                axis,
-                out=out,
-                keepdims=keepdims,
-                initial=initial,
-                where=where,
-            )
+    @deprecated("5.3", alternative="np.nansum", obj_type="method")
+    def nansum(self, axis=None, out=None, keepdims=False, *, initial=None, where=True):
+        if initial is not None:
+            initial = self._to_own_unit(initial)
+        return self._wrap_function(
+            np.nansum,
+            axis,
+            out=out,
+            keepdims=keepdims,
+            initial=initial,
+            where=where,
+        )
 
     def insert(self, obj, values, axis=None):
         """
@@ -2129,7 +2114,7 @@ class SpecificTypeQuantity(Quantity):
         super()._set_unit(unit)
 
 
-def isclose(a, b, rtol=1.0e-5, atol=None, equal_nan=False, **kwargs):
+def isclose(a, b, rtol=1.0e-5, atol=None, equal_nan=False):
     """
     Return a boolean array where two arrays are element-wise equal
     within a tolerance.
@@ -2170,11 +2155,10 @@ def isclose(a, b, rtol=1.0e-5, atol=None, equal_nan=False, **kwargs):
     --------
     allclose
     """
-    unquantified_args = _unquantify_allclose_arguments(a, b, rtol, atol)
-    return np.isclose(*unquantified_args, equal_nan=equal_nan, **kwargs)
+    return np.isclose(*_unquantify_allclose_arguments(a, b, rtol, atol), equal_nan)
 
 
-def allclose(a, b, rtol=1.0e-5, atol=None, equal_nan=False, **kwargs) -> bool:
+def allclose(a, b, rtol=1.0e-5, atol=None, equal_nan=False) -> bool:
     """
     Whether two arrays are element-wise equal within a tolerance.
 
@@ -2214,8 +2198,7 @@ def allclose(a, b, rtol=1.0e-5, atol=None, equal_nan=False, **kwargs) -> bool:
     --------
     isclose
     """
-    unquantified_args = _unquantify_allclose_arguments(a, b, rtol, atol)
-    return np.allclose(*unquantified_args, equal_nan=equal_nan, **kwargs)
+    return np.allclose(*_unquantify_allclose_arguments(a, b, rtol, atol), equal_nan)
 
 
 def _unquantify_allclose_arguments(actual, desired, rtol, atol):
